#!/bin/env perl
# musicxml2tex.pl --- Un convertisseur MusicXML vers MusixTeX
# Copyright 2014 Vincent Belaïche
#
# Author: Vincent Belaïche
#         e-mail : vincent.b.1@hotmail.fr
#
# Version: $Id: musicxml2tex.pl 14 2014-12-16 22:13:56Z vincentb1 $
# Keywords: main
# X-URL: https://gna.org/projects/musicxml2tex/
#
# Ce logiciel est régi par la licence CeCILL soumise au droit français et respectant les principes de
# diffusion des logiciels libres. Vous pouvez utiliser, modifier et/ou redistribuer ce programme sous les
# conditions de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA sur le site
# "http://www.cecill.info".
#
# En contrepartie de l'accessibilité au code source et des droits de copie, de modification et de
# redistribution accordés par cette licence, il n'est offert aux utilisateurs qu'une garantie limitée.  Pour
# les mêmes raisons, seule une responsabilité restreinte pèse sur l'auteur du programme, le titulaire des
# droits patrimoniaux et les concédants successifs.
#
# À cet égard l'attention de l'utilisateur est attirée sur les risques associés au chargement, à
# l'utilisation, à la modification et/ou au développement et à la reproduction du logiciel par l'utilisateur
# étant donné sa spécificité de logiciel libre, qui peut le rendre complexe à manipuler et qui le réserve
# donc à des développeurs et des professionnels avertis possédant des connaissances informatiques
# approfondies.  Les utilisateurs sont donc invités à charger et tester l'adéquation du logiciel à leurs
# besoins dans des conditions permettant d'assurer la sécurité de leurs systèmes et ou de leurs données et,
# plus généralement, à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
#
# Le fait que vous puissiez accéder à cet en-tête signifie que vous avez pris connaissance de la licence
# CeCILL, et que vous en avez accepté les termes.
#
#/ Commentary:

#



#/ Code:
use Getopt::Long;
use XML::Parser;

my $version = "0.0";

my %optctl = ();

&GetOptions(\%optctl, "h", "help", "v", "output=s", "o=s",
"version", "license=s") or &syntaxerror();

foreach $setting (keys %optclt)
{
   if (($setting eq "h") || ($setting eq "help"))
   {
      &help();
   }
    
}

if ($#ARGV != 0)
{
   print "Nom du fichier d'entrée non spécifié\n";
   &syntaxerror();
}


my $basename = $ARGV[0];

open INPUT, "<$basename" or die "Can't open $basename file";
my $parser = XML::Parser->new(Style => 'Tree');
my $tree = $parser->parse(*INPUT);
close(INPUT);



sub help
{
   print "musicxml-to-musictex Help\n\n";

   print "Current Version : $version\n\n";

   print "usage : musicxml-to-musictex [options] <musicxml filename>\n\n";

   print "\
musicxml-to-musictex can be used to construct a LaTeX2e musictex or
musixtex file file from\n";
   print "the specified MusicXML file <musicxml filename>\n";

   print "Optional Arguments:\n\n";
   print "-o <output filename>\n";
   print "\
Set the output file name to <output filename>, otherwise it is set by
default by replacing the extention of <musicxml filename> with
\".tex\"\n";
   print "--output <output filename>\n";
   print "same as -o\n";   
   print "-h                 : help message\n";
   print "-v                 : verbose\n\n";


   die;
}



sub syntaxerror
{
   die "Syntax : musicxml-to-musictex [options] <musicxml-file>\nUse -h for help\n";
}



## end of file musicxml2tex.pl

# Local Variables:
# coding: utf-8
# End:
